==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/util/FileUtil.java <==
package com.samelement.iot_notification.util;

import android.content.Context;
import android.util.Log;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

public class FileUtil {

    public static void writeLog(Context context, String message, boolean clear) {
        try {
            File path = context.getExternalFilesDir(null);
            File file = new File(path, "sam-element-log.txt");
            if (!file.exists()) {
                boolean fileCreated = file.createNewFile();
            } else if (clear) {
                FileUtil.writeToFile(file, "", false);
            }
            DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            Date date = new Date();
            FileUtil.writeToFile(file, message + " (" + dateFormat.format(date) + ")\n", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void writeToFile(File file, String data, boolean append) throws IOException {
        if (!file.exists()) {
            file.createNewFile();
        }

        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file, append));
        outputStreamWriter.write(data);
        outputStreamWriter.close();
    }

    public static String readFromFile(File file) {

        String ret = "";

        try {
            InputStream inputStream = new FileInputStream(file);

            if (inputStream != null) {
                InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
                BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                String receiveString = "";
                StringBuilder stringBuilder = new StringBuilder();

                while ((receiveString = bufferedReader.readLine()) != null) {
                    stringBuilder.append(receiveString);
                }

                inputStream.close();
                ret = stringBuilder.toString();
            }
        } catch (FileNotFoundException e) {
            Log.e("FileUtil", "File not found: " + e.toString());
        } catch (IOException e) {
            Log.e("FileUtil", "Can not read file: " + e.toString());
        }

        return ret;
    }
}

==> 0.5.2.tar.gz: android/src/main/java/com/samelement/iot_notification/util/FileUtil.java <==
package com.samelement.iot_notification.util;

import android.content.Context;
import android.util.Log;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

public class FileUtil {

    public static void writeLog(Context context, String message, boolean clear) {
        try {
            File path = context.getExternalFilesDir(null);
            File file = new File(path, "sam-element-log.txt");
            if (!file.exists()) {
                boolean fileCreated = file.createNewFile();
            } else if (clear) {
                FileUtil.writeToFile(file, "", false);
            }
            DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
            Date date = new Date();
            FileUtil.writeToFile(file, message + " (" + dateFormat.format(date) + ")\n", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void writeToFile(File file, String data, boolean append) throws IOException {
        boolean successfullyCreated = true;
        if (!file.exists()) {
            successfullyCreated = file.createNewFile();
        }

        if (successfullyCreated) {
            OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file, append));
            outputStreamWriter.write(data);
            outputStreamWriter.close();
        }
    }

    public static String readFromFile(File file) {

        String ret = "";

        try {
            InputStream inputStream = new FileInputStream(file);

            InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
            BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
            String receiveString;
            StringBuilder stringBuilder = new StringBuilder();

            while ((receiveString = bufferedReader.readLine()) != null) {
                stringBuilder.append(receiveString);
            }

            inputStream.close();
            ret = stringBuilder.toString();
        } catch (FileNotFoundException e) {
            Log.e("FileUtil", "File not found: " + e.toString());
        } catch (IOException e) {
            Log.e("FileUtil", "Can not read file: " + e.toString());
        }

        return ret;
    }
}
